diff scripts/legacy/@inline/subsref.m @ 30911:b7edac56a810

Add functions to @inline class for Matlab compatibility (Bug #62260). * scripts/legacy/@inline/cat.m, scripts/legacy/@inline/cat.m, scripts/legacy/@inline/disp.m, scripts/legacy/@inline/exist.m, scripts/legacy/@inline/horzcat.m, scripts/legacy/@inline/nargin.m, scripts/legacy/@inline/nargout.m, scripts/legacy/@inline/symvar.m, scripts/legacy/@inline/vertcat.m: New functions * scripts/legacy/module.mk: Add new functions to build system. * scripts/legacy/@inline/argnames.m: scripts/legacy/@inline/char.m, scripts/legacy/@inline/feval.m, scripts/legacy/@inline/formula.m, scripts/legacy/@inline/subsref.m, scripts/legacy/@inline/vectorize.m: Redo documentation. Change FCN input name to FOBJ. * scripts/legacy/@inline/inline.m: Single tweak to documentation. * scripts/legacy/__vectorize__.m: Add note that this function was translated from C++. * scripts/legacy/vectorize.m: Remove incorrect note about function being translated from C++.
author Rik <rik@octave.org>
date Wed, 06 Apr 2022 21:25:58 -0700
parents 796f54d4ddbf
children 597f3ee61a48
line wrap: on
line diff
--- a/scripts/legacy/@inline/subsref.m	Wed Apr 06 16:30:23 2022 -0700
+++ b/scripts/legacy/@inline/subsref.m	Wed Apr 06 21:25:58 2022 -0700
@@ -24,11 +24,11 @@
 ########################################################################
 
 ## -*- texinfo -*-
 ## @deftypefn {} {@var{value} =} subsref (@var{fcn}, @var{idx})
 ## Perform subscripted function call on the inline function object @var{fcn}.
 ## @end deftypefn
 
-function retval = subsref (fcn, idx)
+function retval = subsref (fobj, idx)
 
   if (nargin != 2)
     print_usage ();
@@ -41,9 +41,9 @@
   if (strcmp (idx(1).type, "()"))
     args = idx.subs;
     if (numel (args) > 0)
-      retval = feval (fcn, args{:});
+      retval = feval (fobj, args{:});
     else
-      retval = feval (fcn);
+      retval = feval (fobj);
     endif
   else
     error ("@inline/subsref: invalid subscript type");
@@ -24,11 +24,11 @@
 
 ## -*- texinfo -*-
-## @deftypefn {} {@var{value} =} subsref (@var{fcn}, @var{idx})
-## Perform subscripted function call on the inline function object @var{fcn}.
+## @deftypefn {} {@var{value} =} subsref (@var{fobj}, @var{idx})
+## Perform subscripted function call on the inline function object @var{fobj}.
 ## @end deftypefn
 